"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.group_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    """ID of the Group resource to return.
    To get the group ID, use a [GroupService.List] request.
    """
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id"]) -> None: ...

global___GetGroupRequest = GetGroupRequest

@typing.final
class ListGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to list groups in.
    To get the organization ID, use a [yandex.cloud.organizationmanager.v1.OrganizationService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListGroupsResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [Group.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListGroupsRequest = ListGroupsRequest

@typing.final
class ListGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListGroupsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListGroupsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.group_pb2.Group]:
        """List of Group resources."""

    def __init__(
        self,
        *,
        groups: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.group_pb2.Group] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["groups", b"groups", "next_page_token", b"next_page_token"]) -> None: ...

global___ListGroupsResponse = ListGroupsResponse

@typing.final
class CreateGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to create a group in.
    To get the organization ID, use a [yandex.cloud.organizationmanager.v1.OrganizationService.List] request.
    """
    name: builtins.str
    """Name of the group.
    The name must be unique within the organization.
    """
    description: builtins.str
    """Description of the group."""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "organization_id", b"organization_id"]) -> None: ...

global___CreateGroupRequest = CreateGroupRequest

@typing.final
class CreateGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    """ID of the group that is being created."""
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id"]) -> None: ...

global___CreateGroupMetadata = CreateGroupMetadata

@typing.final
class UpdateGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    """ID of the Group resource to update.
    To get the group ID, use a [GroupService.List] request.
    """
    name: builtins.str
    """Name of the group.
    The name must be unique within the organization.
    """
    description: builtins.str
    """Description of the group."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Group resource are going to be updated."""

    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "group_id", b"group_id", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateGroupRequest = UpdateGroupRequest

@typing.final
class UpdateGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    """ID of the Group resource that is being updated."""
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id"]) -> None: ...

global___UpdateGroupMetadata = UpdateGroupMetadata

@typing.final
class DeleteGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    """ID of the group to delete.
    To get the group ID, use a [GroupService.List] request.
    """
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id"]) -> None: ...

global___DeleteGroupRequest = DeleteGroupRequest

@typing.final
class DeleteGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    """ID of the group that is being deleted."""
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id"]) -> None: ...

global___DeleteGroupMetadata = DeleteGroupMetadata

@typing.final
class ListGroupOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    """ID of the Group resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListGroupOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListGroupOperationsResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListGroupOperationsRequest = ListGroupOperationsRequest

@typing.final
class ListGroupOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListGroupOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListGroupOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified group."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListGroupOperationsResponse = ListGroupOperationsResponse

@typing.final
class ListGroupMembersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    """ID of the Group resource to list members for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListGroupMembersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Acceptable values are 0 to 1000, inclusive. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListGroupMembersResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListGroupMembersRequest = ListGroupMembersRequest

@typing.final
class ListGroupMembersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListGroupMembersRequest.page_size], use the [next_page_token] as the value
    for the [ListGroupMembersRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GroupMember]:
        """List of members for the specified group."""

    def __init__(
        self,
        *,
        members: collections.abc.Iterable[global___GroupMember] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["members", b"members", "next_page_token", b"next_page_token"]) -> None: ...

global___ListGroupMembersResponse = ListGroupMembersResponse

@typing.final
class GroupMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_ID_FIELD_NUMBER: builtins.int
    SUBJECT_TYPE_FIELD_NUMBER: builtins.int
    subject_id: builtins.str
    """ID of the subject."""
    subject_type: builtins.str
    """Type of the subject.

    It can contain one of the following values:
    * `userAccount`: An account on Yandex, added to Yandex Cloud.
    * `federatedUser`: A federated account. This type represents a user from an identity federation, like Active Directory.
    """
    def __init__(
        self,
        *,
        subject_id: builtins.str = ...,
        subject_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_id", b"subject_id", "subject_type", b"subject_type"]) -> None: ...

global___GroupMember = GroupMember

@typing.final
class UpdateGroupMembersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    MEMBER_DELTAS_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    """ID of the group to update.
    To get the group ID, use a [GroupService.List] request.
    """
    @property
    def member_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MemberDelta]:
        """Updates to group members."""

    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
        member_deltas: collections.abc.Iterable[global___MemberDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "member_deltas", b"member_deltas"]) -> None: ...

global___UpdateGroupMembersRequest = UpdateGroupMembersRequest

@typing.final
class UpdateGroupMembersMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    """ID of the group that is being updated."""
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id"]) -> None: ...

global___UpdateGroupMembersMetadata = UpdateGroupMembersMetadata

@typing.final
class MemberDelta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _MemberAction:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MemberActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MemberDelta._MemberAction.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MEMBER_ACTION_UNSPECIFIED: MemberDelta._MemberAction.ValueType  # 0
        ADD: MemberDelta._MemberAction.ValueType  # 1
        """Addition of a group member."""
        REMOVE: MemberDelta._MemberAction.ValueType  # 2
        """Removal of a group member."""

    class MemberAction(_MemberAction, metaclass=_MemberActionEnumTypeWrapper): ...
    MEMBER_ACTION_UNSPECIFIED: MemberDelta.MemberAction.ValueType  # 0
    ADD: MemberDelta.MemberAction.ValueType  # 1
    """Addition of a group member."""
    REMOVE: MemberDelta.MemberAction.ValueType  # 2
    """Removal of a group member."""

    ACTION_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    action: global___MemberDelta.MemberAction.ValueType
    """The action that is being performed on a group member."""
    subject_id: builtins.str
    """ID of the subject that is being added or removed from a group.

    Subject type can be one of following values:
    * `userAccount`: An account on Yandex, added to Yandex Cloud.
    * `federatedUser`: A federated account. This type represents a user from an identity federation, like Active Directory.
    """
    def __init__(
        self,
        *,
        action: global___MemberDelta.MemberAction.ValueType = ...,
        subject_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "subject_id", b"subject_id"]) -> None: ...

global___MemberDelta = MemberDelta



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.compute.v1.snapshot_pb2
import yandex.cloud.compute.v1.snapshot_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SnapshotServiceStub:
    """A set of methods for managing Snapshot resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.GetSnapshotRequest,
        yandex.cloud.compute.v1.snapshot_pb2.Snapshot,
    ]
    """Returns the specified Snapshot resource.

    To get the list of available Snapshot resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotsRequest,
        yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotsResponse,
    ]
    """Retrieves the list of Snapshot resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.CreateSnapshotRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a snapshot of the specified disk."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.UpdateSnapshotRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified snapshot.

    Values of omitted parameters are not changed.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.DeleteSnapshotRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified snapshot.

    Deleting a snapshot removes its data permanently and is irreversible.
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotOperationsRequest,
        yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotOperationsResponse,
    ]
    """Lists operations for the specified snapshot."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the snapshot.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the snapshot."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the snapshot."""

class SnapshotServiceAsyncStub:
    """A set of methods for managing Snapshot resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.GetSnapshotRequest,
        yandex.cloud.compute.v1.snapshot_pb2.Snapshot,
    ]
    """Returns the specified Snapshot resource.

    To get the list of available Snapshot resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotsRequest,
        yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotsResponse,
    ]
    """Retrieves the list of Snapshot resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.CreateSnapshotRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a snapshot of the specified disk."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.UpdateSnapshotRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified snapshot.

    Values of omitted parameters are not changed.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.DeleteSnapshotRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified snapshot.

    Deleting a snapshot removes its data permanently and is irreversible.
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotOperationsRequest,
        yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotOperationsResponse,
    ]
    """Lists operations for the specified snapshot."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the snapshot.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the snapshot."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the snapshot."""

class SnapshotServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Snapshot resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.compute.v1.snapshot_service_pb2.GetSnapshotRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.snapshot_pb2.Snapshot, collections.abc.Awaitable[yandex.cloud.compute.v1.snapshot_pb2.Snapshot]]:
        """Returns the specified Snapshot resource.

        To get the list of available Snapshot resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotsResponse]]:
        """Retrieves the list of Snapshot resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.compute.v1.snapshot_service_pb2.CreateSnapshotRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a snapshot of the specified disk."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.compute.v1.snapshot_service_pb2.UpdateSnapshotRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified snapshot.

        Values of omitted parameters are not changed.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.compute.v1.snapshot_service_pb2.DeleteSnapshotRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified snapshot.

        Deleting a snapshot removes its data permanently and is irreversible.
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotOperationsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.snapshot_service_pb2.ListSnapshotOperationsResponse]]:
        """Lists operations for the specified snapshot."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the snapshot.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the snapshot."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the snapshot."""

def add_SnapshotServiceServicer_to_server(servicer: SnapshotServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import google.type.timeofday_pb2
import sys
import typing
import yandex.cloud.mdb.clickhouse.v1.config.clickhouse_pb2
import yandex.cloud.mdb.clickhouse.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    """A ClickHouse Cluster resource. For more information, see the
    [Cluster](/docs/managed-clickhouse/concepts) section in the Developer's Guide.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Environment:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnvironmentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Environment.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENVIRONMENT_UNSPECIFIED: Cluster._Environment.ValueType  # 0
        PRODUCTION: Cluster._Environment.ValueType  # 1
        """Stable environment with a conservative update policy:
        only hotfixes are applied during regular maintenance.
        """
        PRESTABLE: Cluster._Environment.ValueType  # 2
        """Environment with more aggressive update policy: new versions
        are rolled out irrespective of backward compatibility.
        """

    class Environment(_Environment, metaclass=_EnvironmentEnumTypeWrapper): ...
    ENVIRONMENT_UNSPECIFIED: Cluster.Environment.ValueType  # 0
    PRODUCTION: Cluster.Environment.ValueType  # 1
    """Stable environment with a conservative update policy:
    only hotfixes are applied during regular maintenance.
    """
    PRESTABLE: Cluster.Environment.ValueType  # 2
    """Environment with more aggressive update policy: new versions
    are rolled out irrespective of backward compatibility.
    """

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        """State of the cluster is unknown ([Host.health] for every host in the cluster is UNKNOWN)."""
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is alive and well ([Host.health] for every host in the cluster is ALIVE)."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is inoperable ([Host.health] for every host in the cluster is DEAD)."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is working below capacity ([Host.health] for at least one host in the cluster is not ALIVE)."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    """State of the cluster is unknown ([Host.health] for every host in the cluster is UNKNOWN)."""
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is alive and well ([Host.health] for every host in the cluster is ALIVE)."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is inoperable ([Host.health] for every host in the cluster is DEAD)."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is working below capacity ([Host.health] for at least one host in the cluster is not ALIVE)."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        UPDATING: Cluster._Status.ValueType  # 4
        """Cluster is being updated."""
        STOPPING: Cluster._Status.ValueType  # 5
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 6
        """Cluster stopped."""
        STARTING: Cluster._Status.ValueType  # 7
        """Cluster is starting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    UPDATING: Cluster.Status.ValueType  # 4
    """Cluster is being updated."""
    STOPPING: Cluster.Status.ValueType  # 5
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 6
    """Cluster stopped."""
    STARTING: Cluster.Status.ValueType  # 7
    """Cluster is starting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the ClickHouse cluster.
    This ID is assigned by MDB at creation time.
    """
    folder_id: builtins.str
    """ID of the folder that the ClickHouse cluster belongs to."""
    name: builtins.str
    """Name of the ClickHouse cluster.
    The name is unique within the folder. 1-63 characters long.
    """
    description: builtins.str
    """Description of the ClickHouse cluster. 0-256 characters long."""
    environment: global___Cluster.Environment.ValueType
    """Deployment environment of the ClickHouse cluster."""
    network_id: builtins.str
    """ID of the network that the cluster belongs to."""
    health: global___Cluster.Health.ValueType
    """Aggregated cluster health."""
    status: global___Cluster.Status.ValueType
    """Current state of the cluster."""
    service_account_id: builtins.str
    """ID of the service account used for access to Object Storage."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the ClickHouse cluster as `key:value` pairs. Maximum 64 per resource."""

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Description of monitoring systems relevant to the ClickHouse cluster."""

    @property
    def config(self) -> global___ClusterConfig:
        """Configuration of the ClickHouse cluster."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.clickhouse.v1.maintenance_pb2.MaintenanceWindow:
        """Maintenance window for the cluster."""

    @property
    def planned_operation(self) -> yandex.cloud.mdb.clickhouse.v1.maintenance_pb2.MaintenanceOperation:
        """Planned maintenance operation to be started for the cluster within the nearest [maintenance_window]."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: global___Cluster.Environment.ValueType = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        config: global___ClusterConfig | None = ...,
        network_id: builtins.str = ...,
        health: global___Cluster.Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        service_account_id: builtins.str = ...,
        maintenance_window: yandex.cloud.mdb.clickhouse.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.mdb.clickhouse.v1.maintenance_pb2.MaintenanceOperation | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "maintenance_window", b"maintenance_window", "planned_operation", b"planned_operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "health", b"health", "id", b"id", "labels", b"labels", "maintenance_window", b"maintenance_window", "monitoring", b"monitoring", "name", b"name", "network_id", b"network_id", "planned_operation", b"planned_operation", "security_group_ids", b"security_group_ids", "service_account_id", b"service_account_id", "status", b"status"]) -> None: ...

global___Cluster = Cluster

@typing.final
class Monitoring(google.protobuf.message.Message):
    """Monitoring system metadata."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system charts for the ClickHouse cluster."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Clickhouse(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONFIG_FIELD_NUMBER: builtins.int
        RESOURCES_FIELD_NUMBER: builtins.int
        @property
        def config(self) -> yandex.cloud.mdb.clickhouse.v1.config.clickhouse_pb2.ClickhouseConfigSet:
            """Configuration settings of a ClickHouse server."""

        @property
        def resources(self) -> global___Resources:
            """Resources allocated to ClickHouse hosts."""

        def __init__(
            self,
            *,
            config: yandex.cloud.mdb.clickhouse.v1.config.clickhouse_pb2.ClickhouseConfigSet | None = ...,
            resources: global___Resources | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["config", b"config", "resources", b"resources"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["config", b"config", "resources", b"resources"]) -> None: ...

    @typing.final
    class Zookeeper(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESOURCES_FIELD_NUMBER: builtins.int
        @property
        def resources(self) -> global___Resources:
            """Resources allocated to ZooKeeper hosts."""

        def __init__(
            self,
            *,
            resources: global___Resources | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

    VERSION_FIELD_NUMBER: builtins.int
    CLICKHOUSE_FIELD_NUMBER: builtins.int
    ZOOKEEPER_FIELD_NUMBER: builtins.int
    BACKUP_WINDOW_START_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    CLOUD_STORAGE_FIELD_NUMBER: builtins.int
    SQL_DATABASE_MANAGEMENT_FIELD_NUMBER: builtins.int
    SQL_USER_MANAGEMENT_FIELD_NUMBER: builtins.int
    EMBEDDED_KEEPER_FIELD_NUMBER: builtins.int
    BACKUP_RETAIN_PERIOD_DAYS_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Version of the ClickHouse server software."""
    @property
    def clickhouse(self) -> global___ClusterConfig.Clickhouse:
        """Configuration and resource allocation for ClickHouse hosts."""

    @property
    def zookeeper(self) -> global___ClusterConfig.Zookeeper:
        """Configuration and resource allocation for ZooKeeper hosts."""

    @property
    def backup_window_start(self) -> google.type.timeofday_pb2.TimeOfDay:
        """Time to start the daily backup, in the UTC timezone."""

    @property
    def access(self) -> global___Access:
        """Access policy for external services."""

    @property
    def cloud_storage(self) -> global___CloudStorage: ...
    @property
    def sql_database_management(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Whether database management through SQL commands is enabled."""

    @property
    def sql_user_management(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Whether user management through SQL commands is enabled."""

    @property
    def embedded_keeper(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Whether cluster should use embedded Keeper instead of Zookeeper."""

    @property
    def backup_retain_period_days(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Retain period of automatically created backup in days"""

    def __init__(
        self,
        *,
        version: builtins.str = ...,
        clickhouse: global___ClusterConfig.Clickhouse | None = ...,
        zookeeper: global___ClusterConfig.Zookeeper | None = ...,
        backup_window_start: google.type.timeofday_pb2.TimeOfDay | None = ...,
        access: global___Access | None = ...,
        cloud_storage: global___CloudStorage | None = ...,
        sql_database_management: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        sql_user_management: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        embedded_keeper: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        backup_retain_period_days: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access", b"access", "backup_retain_period_days", b"backup_retain_period_days", "backup_window_start", b"backup_window_start", "clickhouse", b"clickhouse", "cloud_storage", b"cloud_storage", "embedded_keeper", b"embedded_keeper", "sql_database_management", b"sql_database_management", "sql_user_management", b"sql_user_management", "zookeeper", b"zookeeper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "backup_retain_period_days", b"backup_retain_period_days", "backup_window_start", b"backup_window_start", "clickhouse", b"clickhouse", "cloud_storage", b"cloud_storage", "embedded_keeper", b"embedded_keeper", "sql_database_management", b"sql_database_management", "sql_user_management", b"sql_user_management", "version", b"version", "zookeeper", b"zookeeper"]) -> None: ...

global___ClusterConfig = ClusterConfig

@typing.final
class Shard(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the shard."""
    cluster_id: builtins.str
    """ID of the cluster that the shard belongs to."""
    @property
    def config(self) -> global___ShardConfig:
        """Configuration of the shard."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        config: global___ShardConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "config", b"config", "name", b"name"]) -> None: ...

global___Shard = Shard

@typing.final
class ShardGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SHARD_NAMES_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the shard group."""
    cluster_id: builtins.str
    """ID of the ClickHouse cluster that the shard group belongs to."""
    description: builtins.str
    """Description of the shard group. 0-256 characters long."""
    @property
    def shard_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of shard names contained in the shard group."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        description: builtins.str = ...,
        shard_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "description", b"description", "name", b"name", "shard_names", b"shard_names"]) -> None: ...

global___ShardGroup = ShardGroup

@typing.final
class ShardConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Clickhouse(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONFIG_FIELD_NUMBER: builtins.int
        RESOURCES_FIELD_NUMBER: builtins.int
        WEIGHT_FIELD_NUMBER: builtins.int
        @property
        def config(self) -> yandex.cloud.mdb.clickhouse.v1.config.clickhouse_pb2.ClickhouseConfigSet:
            """ClickHouse settings for a shard."""

        @property
        def resources(self) -> global___Resources:
            """Computational resources for a shard."""

        @property
        def weight(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Relative weight of a shard considered when writing data to the cluster.
            For details, see [ClickHouse documentation](https://clickhouse.com/docs/en/operations/table_engines/distributed/).
            """

        def __init__(
            self,
            *,
            config: yandex.cloud.mdb.clickhouse.v1.config.clickhouse_pb2.ClickhouseConfigSet | None = ...,
            resources: global___Resources | None = ...,
            weight: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["config", b"config", "resources", b"resources", "weight", b"weight"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["config", b"config", "resources", b"resources", "weight", b"weight"]) -> None: ...

    CLICKHOUSE_FIELD_NUMBER: builtins.int
    @property
    def clickhouse(self) -> global___ShardConfig.Clickhouse:
        """ClickHouse configuration for a shard."""

    def __init__(
        self,
        *,
        clickhouse: global___ShardConfig.Clickhouse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["clickhouse", b"clickhouse"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clickhouse", b"clickhouse"]) -> None: ...

global___ShardConfig = ShardConfig

@typing.final
class Host(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Host._Type.ValueType  # 0
        """Host type is unspecified. Default value."""
        CLICKHOUSE: Host._Type.ValueType  # 1
        """ClickHouse host."""
        ZOOKEEPER: Host._Type.ValueType  # 2
        """ZooKeeper host."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Host.Type.ValueType  # 0
    """Host type is unspecified. Default value."""
    CLICKHOUSE: Host.Type.ValueType  # 1
    """ClickHouse host."""
    ZOOKEEPER: Host.Type.ValueType  # 2
    """ZooKeeper host."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: Host._Health.ValueType  # 0
        """Health of the host is unknown."""
        ALIVE: Host._Health.ValueType  # 1
        """The host is performing all its functions normally."""
        DEAD: Host._Health.ValueType  # 2
        """The host is inoperable, and cannot perform any of its essential functions."""
        DEGRADED: Host._Health.ValueType  # 3
        """The host is degraded, and can perform only some of its essential functions."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    UNKNOWN: Host.Health.ValueType  # 0
    """Health of the host is unknown."""
    ALIVE: Host.Health.ValueType  # 1
    """The host is performing all its functions normally."""
    DEAD: Host.Health.ValueType  # 2
    """The host is inoperable, and cannot perform any of its essential functions."""
    DEGRADED: Host.Health.ValueType  # 3
    """The host is degraded, and can perform only some of its essential functions."""

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    SERVICES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    SHARD_NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the ClickHouse host. The host name is assigned by MDB at creation time, and cannot be changed.
    1-63 characters long.

    The name is unique across all MDB hosts that exist on the platform, as it defines the FQDN of the host.
    """
    cluster_id: builtins.str
    """ID of the ClickHouse host. The ID is assigned by MDB at creation time."""
    zone_id: builtins.str
    """ID of the availability zone where the ClickHouse host resides."""
    type: global___Host.Type.ValueType
    """Type of the host. If the field has default value, it is not returned in the response."""
    health: global___Host.Health.ValueType
    """Aggregated health of the host. If the field has default value, it is not returned in the response."""
    subnet_id: builtins.str
    """ID of the subnet that the host belongs to."""
    assign_public_ip: builtins.bool
    """Flag showing public IP assignment status to this host."""
    shard_name: builtins.str
    @property
    def resources(self) -> global___Resources:
        """Resources allocated to the ClickHouse host."""

    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Service]:
        """Services provided by the host."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        type: global___Host.Type.ValueType = ...,
        resources: global___Resources | None = ...,
        health: global___Host.Health.ValueType = ...,
        services: collections.abc.Iterable[global___Service] | None = ...,
        subnet_id: builtins.str = ...,
        assign_public_ip: builtins.bool = ...,
        shard_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "cluster_id", b"cluster_id", "health", b"health", "name", b"name", "resources", b"resources", "services", b"services", "shard_name", b"shard_name", "subnet_id", b"subnet_id", "type", b"type", "zone_id", b"zone_id"]) -> None: ...

global___Host = Host

@typing.final
class Service(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Service._Type.ValueType  # 0
        """Service type of the host is unspecified. Default value."""
        CLICKHOUSE: Service._Type.ValueType  # 1
        """The host is a ClickHouse server."""
        ZOOKEEPER: Service._Type.ValueType  # 2
        """The host is a ZooKeeper server."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Service.Type.ValueType  # 0
    """Service type of the host is unspecified. Default value."""
    CLICKHOUSE: Service.Type.ValueType  # 1
    """The host is a ClickHouse server."""
    ZOOKEEPER: Service.Type.ValueType  # 2
    """The host is a ZooKeeper server."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: Service._Health.ValueType  # 0
        """Health of the server is unknown. Default value."""
        ALIVE: Service._Health.ValueType  # 1
        """The server is working normally."""
        DEAD: Service._Health.ValueType  # 2
        """The server is dead or unresponsive."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    UNKNOWN: Service.Health.ValueType  # 0
    """Health of the server is unknown. Default value."""
    ALIVE: Service.Health.ValueType  # 1
    """The server is working normally."""
    DEAD: Service.Health.ValueType  # 2
    """The server is dead or unresponsive."""

    TYPE_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    type: global___Service.Type.ValueType
    """Type of the service provided by the host. If the field has default value, it is not returned in the response."""
    health: global___Service.Health.ValueType
    """Aggregated health of the service. If the field has default value, it is not returned in the response."""
    def __init__(
        self,
        *,
        type: global___Service.Type.ValueType = ...,
        health: global___Service.Health.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["health", b"health", "type", b"type"]) -> None: ...

global___Service = Service

@typing.final
class Resources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources available to a host (CPU, memory etc.).
    All available presets are listed in the [documentation](/docs/managed-clickhouse/concepts/instance-types)
    """
    disk_size: builtins.int
    """Volume of the storage available to a host, in bytes."""
    disk_type_id: builtins.str
    """Type of the storage environment for the host.
    Possible values:
    * network-hdd - network HDD drive,
    * network-ssd - network SSD drive,
    * local-ssd - local SSD storage.
    """
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class Access(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_LENS_FIELD_NUMBER: builtins.int
    WEB_SQL_FIELD_NUMBER: builtins.int
    METRIKA_FIELD_NUMBER: builtins.int
    SERVERLESS_FIELD_NUMBER: builtins.int
    DATA_TRANSFER_FIELD_NUMBER: builtins.int
    YANDEX_QUERY_FIELD_NUMBER: builtins.int
    data_lens: builtins.bool
    """Allow to export data from the cluster to DataLens."""
    web_sql: builtins.bool
    """Allow SQL queries to the cluster databases from the management console.

    See [SQL queries in the management console](/docs/managed-clickhouse/operations/web-sql-query) for more details.
    """
    metrika: builtins.bool
    """Allow to import data from Yandex Metrica and AppMetrica to the cluster.

    See [AppMetrica documentation](https://appmetrica.yandex.com/docs/cloud/index.html) for more details.
    """
    serverless: builtins.bool
    """Allow access to cluster for Serverless."""
    data_transfer: builtins.bool
    """Allow access for DataTransfer"""
    yandex_query: builtins.bool
    """Allow access for Query"""
    def __init__(
        self,
        *,
        data_lens: builtins.bool = ...,
        web_sql: builtins.bool = ...,
        metrika: builtins.bool = ...,
        serverless: builtins.bool = ...,
        data_transfer: builtins.bool = ...,
        yandex_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data_lens", b"data_lens", "data_transfer", b"data_transfer", "metrika", b"metrika", "serverless", b"serverless", "web_sql", b"web_sql", "yandex_query", b"yandex_query"]) -> None: ...

global___Access = Access

@typing.final
class CloudStorage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    MOVE_FACTOR_FIELD_NUMBER: builtins.int
    DATA_CACHE_ENABLED_FIELD_NUMBER: builtins.int
    DATA_CACHE_MAX_SIZE_FIELD_NUMBER: builtins.int
    PREFER_NOT_TO_MERGE_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """Whether to use Object Storage for storing ClickHouse data."""
    @property
    def move_factor(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def data_cache_enabled(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def data_cache_max_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def prefer_not_to_merge(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        move_factor: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        data_cache_enabled: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        data_cache_max_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        prefer_not_to_merge: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_cache_enabled", b"data_cache_enabled", "data_cache_max_size", b"data_cache_max_size", "move_factor", b"move_factor", "prefer_not_to_merge", b"prefer_not_to_merge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data_cache_enabled", b"data_cache_enabled", "data_cache_max_size", b"data_cache_max_size", "enabled", b"enabled", "move_factor", b"move_factor", "prefer_not_to_merge", b"prefer_not_to_merge"]) -> None: ...

global___CloudStorage = CloudStorage



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.video.v1.thumbnail_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListThumbnailRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    page_size: builtins.int
    """The maximum number of the results per page to return. Default value: 100."""
    page_token: builtins.str
    """Page token for getting the next page of the result."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListThumbnailRequest = ListThumbnailRequest

@typing.final
class ListThumbnailResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAILS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page."""
    @property
    def thumbnails(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.thumbnail_pb2.Thumbnail]:
        """List of thumbnails."""

    def __init__(
        self,
        *,
        thumbnails: collections.abc.Iterable[yandex.cloud.video.v1.thumbnail_pb2.Thumbnail] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "thumbnails", b"thumbnails"]) -> None: ...

global___ListThumbnailResponse = ListThumbnailResponse

@typing.final
class CreateThumbnailRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___CreateThumbnailRequest = CreateThumbnailRequest

@typing.final
class CreateThumbnailMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thumbnail_id", b"thumbnail_id"]) -> None: ...

global___CreateThumbnailMetadata = CreateThumbnailMetadata

@typing.final
class BatchGenerateDownloadURLsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    THUMBNAIL_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    @property
    def thumbnail_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of thumbnails IDs."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        thumbnail_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "thumbnail_ids", b"thumbnail_ids"]) -> None: ...

global___BatchGenerateDownloadURLsRequest = BatchGenerateDownloadURLsRequest

@typing.final
class BatchGenerateDownloadURLsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNLOAD_URLS_FIELD_NUMBER: builtins.int
    @property
    def download_urls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThumbnailDownloadURL]:
        """List of download urls."""

    def __init__(
        self,
        *,
        download_urls: collections.abc.Iterable[global___ThumbnailDownloadURL] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["download_urls", b"download_urls"]) -> None: ...

global___BatchGenerateDownloadURLsResponse = BatchGenerateDownloadURLsResponse

@typing.final
class ThumbnailDownloadURL(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    download_url: builtins.str
    """Download url."""
    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
        download_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["download_url", b"download_url", "thumbnail_id", b"thumbnail_id"]) -> None: ...

global___ThumbnailDownloadURL = ThumbnailDownloadURL

@typing.final
class GenerateThumbnailUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thumbnail_id", b"thumbnail_id"]) -> None: ...

global___GenerateThumbnailUploadURLRequest = GenerateThumbnailUploadURLRequest

@typing.final
class GenerateThumbnailUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url."""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["upload_url", b"upload_url"]) -> None: ...

global___GenerateThumbnailUploadURLResponse = GenerateThumbnailUploadURLResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.iam.v1.resource_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Service(google.protobuf.message.Message):
    """A Service."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Service._Status.ValueType  # 0
        ENABLED: Service._Status.ValueType  # 1
        """The service is enabled."""
        PAUSED: Service._Status.ValueType  # 2
        """The service is paused."""
        DISABLED: Service._Status.ValueType  # 3
        """The service is disabled."""
        ENABLING: Service._Status.ValueType  # 4
        """The service is being enabled."""
        RESUMING: Service._Status.ValueType  # 5
        """The service is being resumed."""
        PAUSING: Service._Status.ValueType  # 6
        """The service is being paused."""
        DISABLING: Service._Status.ValueType  # 7
        """The service is being disabled."""
        ERROR: Service._Status.ValueType  # 8
        """The service is in error state."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Service.Status.ValueType  # 0
    ENABLED: Service.Status.ValueType  # 1
    """The service is enabled."""
    PAUSED: Service.Status.ValueType  # 2
    """The service is paused."""
    DISABLED: Service.Status.ValueType  # 3
    """The service is disabled."""
    ENABLING: Service.Status.ValueType  # 4
    """The service is being enabled."""
    RESUMING: Service.Status.ValueType  # 5
    """The service is being resumed."""
    PAUSING: Service.Status.ValueType  # 6
    """The service is being paused."""
    DISABLING: Service.Status.ValueType  # 7
    """The service is being disabled."""
    ERROR: Service.Status.ValueType  # 8
    """The service is in error state."""

    SERVICE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    service_id: builtins.str
    """ID of the service."""
    status: global___Service.Status.ValueType
    """Current status of the service."""
    @property
    def resource(self) -> yandex.cloud.iam.v1.resource_pb2.Resource:
        """Resource that the service belongs to."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of the last status update of the service."""

    def __init__(
        self,
        *,
        service_id: builtins.str = ...,
        resource: yandex.cloud.iam.v1.resource_pb2.Resource | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        status: global___Service.Status.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource", b"resource", "service_id", b"service_id", "status", b"status", "updated_at", b"updated_at"]) -> None: ...

global___Service = Service



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/agent_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/loadtesting/agent/v1/agent_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\"\xb9\x02\n\x17\x43laimAgentStatusRequest\x12\x19\n\x11\x61gent_instance_id\x18\x01 \x01(\t\x12Q\n\x06status\x18\x02 \x01(\x0e\x32\x41.yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusRequest.Status\x12\x16\n\x0estatus_message\x18\x03 \x01(\t\"\x97\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x12\n\x0eREADY_FOR_TEST\x10\x01\x12\x12\n\x0ePREPARING_TEST\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\x0f\n\x0bTANK_FAILED\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x17\n\x13UPLOADING_ARTIFACTS\x10\x06\x12\t\n\x05\x45RROR\x10\x07\"(\n\x18\x43laimAgentStatusResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x32\xe0\x01\n\x0c\x41gentService\x12\xcf\x01\n\x0b\x43laimStatus\x12:.yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusRequest\x1a;.yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusResponse\"G\x82\xd3\xe4\x93\x02\x41\"</loadtesting/agent/v1/agents/{agent_instance_id}/claimStatus:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.agent.v1.agent_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent'
  _AGENTSERVICE.methods_by_name['ClaimStatus']._options = None
  _AGENTSERVICE.methods_by_name['ClaimStatus']._serialized_options = b'\202\323\344\223\002A\"</loadtesting/agent/v1/agents/{agent_instance_id}/claimStatus:\001*'
  _globals['_CLAIMAGENTSTATUSREQUEST']._serialized_start=123
  _globals['_CLAIMAGENTSTATUSREQUEST']._serialized_end=436
  _globals['_CLAIMAGENTSTATUSREQUEST_STATUS']._serialized_start=285
  _globals['_CLAIMAGENTSTATUSREQUEST_STATUS']._serialized_end=436
  _globals['_CLAIMAGENTSTATUSRESPONSE']._serialized_start=438
  _globals['_CLAIMAGENTSTATUSRESPONSE']._serialized_end=478
  _globals['_AGENTSERVICE']._serialized_start=481
  _globals['_AGENTSERVICE']._serialized_end=705
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.oauth.claims_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListMembersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the Organization resource to list members for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListMembersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Acceptable values are 0 to 1000, inclusive. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListMembersResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListMembersRequest = ListMembersRequest

@typing.final
class ListMembersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class OrganizationUser(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SUBJECT_CLAIMS_FIELD_NUMBER: builtins.int
        @property
        def subject_claims(self) -> yandex.cloud.oauth.claims_pb2.SubjectClaims:
            """OpenID standard claims with additional Cloud Organization claims."""

        def __init__(
            self,
            *,
            subject_claims: yandex.cloud.oauth.claims_pb2.SubjectClaims | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["subject_claims", b"subject_claims"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["subject_claims", b"subject_claims"]) -> None: ...

    USERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListMembersRequest.page_size], use the [next_page_token] as the value
    for the [ListMembersRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListMembersResponse.OrganizationUser]:
        """List of users for the specified organization."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[global___ListMembersResponse.OrganizationUser] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "users", b"users"]) -> None: ...

global___ListMembersResponse = ListMembersResponse

@typing.final
class DeleteMembershipRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to delete membership."""
    subject_id: builtins.str
    """ID of the subject that is being deleted from organization.
    By default equals to authenticated subject.
    """
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        subject_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "subject_id", b"subject_id"]) -> None: ...

global___DeleteMembershipRequest = DeleteMembershipRequest

@typing.final
class DeleteMembershipMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to delete membership."""
    subject_id: builtins.str
    """ID of the subject that is being deleted from organization."""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        subject_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "subject_id", b"subject_id"]) -> None: ...

global___DeleteMembershipMetadata = DeleteMembershipMetadata

@typing.final
class DeleteMembershipResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to delete membership."""
    subject_id: builtins.str
    """ID of the subject that is being deleted from organization."""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        subject_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "subject_id", b"subject_id"]) -> None: ...

global___DeleteMembershipResponse = DeleteMembershipResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.datatransfer.v1.endpoint_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TransferType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TransferTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TransferType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRANSFER_TYPE_UNSPECIFIED: _TransferType.ValueType  # 0
    SNAPSHOT_AND_INCREMENT: _TransferType.ValueType  # 1
    """Snapshot and increment"""
    SNAPSHOT_ONLY: _TransferType.ValueType  # 2
    """Snapshot"""
    INCREMENT_ONLY: _TransferType.ValueType  # 3
    """Increment"""

class TransferType(_TransferType, metaclass=_TransferTypeEnumTypeWrapper): ...

TRANSFER_TYPE_UNSPECIFIED: TransferType.ValueType  # 0
SNAPSHOT_AND_INCREMENT: TransferType.ValueType  # 1
"""Snapshot and increment"""
SNAPSHOT_ONLY: TransferType.ValueType  # 2
"""Snapshot"""
INCREMENT_ONLY: TransferType.ValueType  # 3
"""Increment"""
global___TransferType = TransferType

class _TransferStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TransferStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TransferStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRANSFER_STATUS_UNSPECIFIED: _TransferStatus.ValueType  # 0
    CREATING: _TransferStatus.ValueType  # 1
    """Transfer does some work before running"""
    CREATED: _TransferStatus.ValueType  # 2
    """Transfer created but not started by user"""
    RUNNING: _TransferStatus.ValueType  # 3
    """Transfer currently doing replication work"""
    STOPPING: _TransferStatus.ValueType  # 4
    """Transfer shutdown"""
    STOPPED: _TransferStatus.ValueType  # 5
    """Transfer stopped by user"""
    ERROR: _TransferStatus.ValueType  # 6
    """Transfer stopped by system"""
    SNAPSHOTTING: _TransferStatus.ValueType  # 7
    """Transfer copy snapshot"""
    DONE: _TransferStatus.ValueType  # 8
    """Transfer reach terminal phase"""

class TransferStatus(_TransferStatus, metaclass=_TransferStatusEnumTypeWrapper): ...

TRANSFER_STATUS_UNSPECIFIED: TransferStatus.ValueType  # 0
CREATING: TransferStatus.ValueType  # 1
"""Transfer does some work before running"""
CREATED: TransferStatus.ValueType  # 2
"""Transfer created but not started by user"""
RUNNING: TransferStatus.ValueType  # 3
"""Transfer currently doing replication work"""
STOPPING: TransferStatus.ValueType  # 4
"""Transfer shutdown"""
STOPPED: TransferStatus.ValueType  # 5
"""Transfer stopped by user"""
ERROR: TransferStatus.ValueType  # 6
"""Transfer stopped by system"""
SNAPSHOTTING: TransferStatus.ValueType  # 7
"""Transfer copy snapshot"""
DONE: TransferStatus.ValueType  # 8
"""Transfer reach terminal phase"""
global___TransferStatus = TransferStatus

@typing.final
class Transfer(google.protobuf.message.Message):
    """Transfer core entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    WARNING_FIELD_NUMBER: builtins.int
    TRANSFORMATION_FIELD_NUMBER: builtins.int
    PRESTABLE_FIELD_NUMBER: builtins.int
    id: builtins.str
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    status: global___TransferStatus.ValueType
    type: global___TransferType.ValueType
    warning: builtins.str
    prestable: builtins.bool
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def source(self) -> yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint: ...
    @property
    def target(self) -> yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint: ...
    @property
    def runtime(self) -> global___Runtime: ...
    @property
    def transformation(self) -> global___Transformation: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        source: yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint | None = ...,
        target: yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint | None = ...,
        runtime: global___Runtime | None = ...,
        status: global___TransferStatus.ValueType = ...,
        type: global___TransferType.ValueType = ...,
        warning: builtins.str = ...,
        transformation: global___Transformation | None = ...,
        prestable: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["runtime", b"runtime", "source", b"source", "target", b"target", "transformation", b"transformation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "prestable", b"prestable", "runtime", b"runtime", "source", b"source", "status", b"status", "target", b"target", "transformation", b"transformation", "type", b"type", "warning", b"warning"]) -> None: ...

global___Transfer = Transfer

@typing.final
class Runtime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    YC_RUNTIME_FIELD_NUMBER: builtins.int
    @property
    def yc_runtime(self) -> global___YcRuntime: ...
    def __init__(
        self,
        *,
        yc_runtime: global___YcRuntime | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["runtime", b"runtime", "yc_runtime", b"yc_runtime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["runtime", b"runtime", "yc_runtime", b"yc_runtime"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["runtime", b"runtime"]) -> typing.Literal["yc_runtime"] | None: ...

global___Runtime = Runtime

@typing.final
class ShardingUploadParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_COUNT_FIELD_NUMBER: builtins.int
    PROCESS_COUNT_FIELD_NUMBER: builtins.int
    job_count: builtins.int
    process_count: builtins.int
    def __init__(
        self,
        *,
        job_count: builtins.int = ...,
        process_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_count", b"job_count", "process_count", b"process_count"]) -> None: ...

global___ShardingUploadParams = ShardingUploadParams

@typing.final
class YcRuntime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_COUNT_FIELD_NUMBER: builtins.int
    UPLOAD_SHARD_PARAMS_FIELD_NUMBER: builtins.int
    job_count: builtins.int
    @property
    def upload_shard_params(self) -> global___ShardingUploadParams: ...
    def __init__(
        self,
        *,
        job_count: builtins.int = ...,
        upload_shard_params: global___ShardingUploadParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["upload_shard_params", b"upload_shard_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["job_count", b"job_count", "upload_shard_params", b"upload_shard_params"]) -> None: ...

global___YcRuntime = YcRuntime

@typing.final
class MaskFunction(google.protobuf.message.Message):
    """Mask function"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MASK_FUNCTION_HASH_FIELD_NUMBER: builtins.int
    @property
    def mask_function_hash(self) -> global___MaskFunctionHash:
        """Hash mask function"""

    def __init__(
        self,
        *,
        mask_function_hash: global___MaskFunctionHash | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mask_function", b"mask_function", "mask_function_hash", b"mask_function_hash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["mask_function", b"mask_function", "mask_function_hash", b"mask_function_hash"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["mask_function", b"mask_function"]) -> typing.Literal["mask_function_hash"] | None: ...

global___MaskFunction = MaskFunction

@typing.final
class MaskFunctionHash(google.protobuf.message.Message):
    """Hash data using HMAC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_DEFINED_SALT_FIELD_NUMBER: builtins.int
    user_defined_salt: builtins.str
    """This string will be used in the HMAC(sha256, salt) function applied to the
    column data.
    """
    def __init__(
        self,
        *,
        user_defined_salt: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_defined_salt", b"user_defined_salt"]) -> None: ...

global___MaskFunctionHash = MaskFunctionHash

@typing.final
class TablesFilter(google.protobuf.message.Message):
    """Filter tables using lists of included and excluded tables."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_TABLES_FIELD_NUMBER: builtins.int
    EXCLUDE_TABLES_FIELD_NUMBER: builtins.int
    @property
    def include_tables(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of tables that will be included to transfer"""

    @property
    def exclude_tables(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of tables that will be excluded to transfer"""

    def __init__(
        self,
        *,
        include_tables: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_tables: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exclude_tables", b"exclude_tables", "include_tables", b"include_tables"]) -> None: ...

global___TablesFilter = TablesFilter

@typing.final
class ColumnsFilter(google.protobuf.message.Message):
    """Filter columns using lists of included and excluded columns."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_COLUMNS_FIELD_NUMBER: builtins.int
    EXCLUDE_COLUMNS_FIELD_NUMBER: builtins.int
    @property
    def include_columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of columns that will be included to transfer"""

    @property
    def exclude_columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of columns that will be excluded to transfer"""

    def __init__(
        self,
        *,
        include_columns: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_columns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exclude_columns", b"exclude_columns", "include_columns", b"include_columns"]) -> None: ...

global___ColumnsFilter = ColumnsFilter

@typing.final
class MaskFieldTransformer(google.protobuf.message.Message):
    """Mask field transformer allows you to hash data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    FUNCTION_FIELD_NUMBER: builtins.int
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables"""

    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Specify the name of the column for data masking (a regular expression)."""

    @property
    def function(self) -> global___MaskFunction:
        """Mask function"""

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        columns: collections.abc.Iterable[builtins.str] | None = ...,
        function: global___MaskFunction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["function", b"function", "tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "function", b"function", "tables", b"tables"]) -> None: ...

global___MaskFieldTransformer = MaskFieldTransformer

@typing.final
class FilterColumnsTransformer(google.protobuf.message.Message):
    """Set up a list of table columns to transfer"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    @property
    def tables(self) -> global___TablesFilter:
        """List of the tables to filter using lists of included and excluded tables."""

    @property
    def columns(self) -> global___ColumnsFilter:
        """List of the columns to transfer to the target tables using lists of included and
        excluded columns.
        """

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        columns: global___ColumnsFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["columns", b"columns", "tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "tables", b"tables"]) -> None: ...

global___FilterColumnsTransformer = FilterColumnsTransformer

@typing.final
class Table(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_SPACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    name_space: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        name_space: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "name_space", b"name_space"]) -> None: ...

global___Table = Table

@typing.final
class RenameTable(google.protobuf.message.Message):
    """Specify rule for renaming table"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGINAL_NAME_FIELD_NUMBER: builtins.int
    NEW_NAME_FIELD_NUMBER: builtins.int
    @property
    def original_name(self) -> global___Table:
        """Specify the current names of the table in the source"""

    @property
    def new_name(self) -> global___Table:
        """Specify the new names for this table in the target"""

    def __init__(
        self,
        *,
        original_name: global___Table | None = ...,
        new_name: global___Table | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["new_name", b"new_name", "original_name", b"original_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["new_name", b"new_name", "original_name", b"original_name"]) -> None: ...

global___RenameTable = RenameTable

@typing.final
class RenameTablesTransformer(google.protobuf.message.Message):
    """Set rules for renaming tables by specifying the current names of the tables in
    the source and new names for these tables in the target.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RENAME_TABLES_FIELD_NUMBER: builtins.int
    @property
    def rename_tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RenameTable]:
        """List of renaming rules"""

    def __init__(
        self,
        *,
        rename_tables: collections.abc.Iterable[global___RenameTable] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rename_tables", b"rename_tables"]) -> None: ...

global___RenameTablesTransformer = RenameTablesTransformer

@typing.final
class ReplacePrimaryKeyTransformer(google.protobuf.message.Message):
    """Override primary keys"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    KEYS_FIELD_NUMBER: builtins.int
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables"""

    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of columns to be used as primary keys"""

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        keys: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["keys", b"keys", "tables", b"tables"]) -> None: ...

global___ReplacePrimaryKeyTransformer = ReplacePrimaryKeyTransformer

@typing.final
class ToStringTransformer(google.protobuf.message.Message):
    """Convert column values to strings
    The values will be converted depending on the source type
    Conversion rules are described here:
    https://cloud.yandex.com/en/docs/data-transfer/concepts/data-transformation#convert-to-string
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables"""

    @property
    def columns(self) -> global___ColumnsFilter:
        """List of included and excluded columns"""

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        columns: global___ColumnsFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["columns", b"columns", "tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "tables", b"tables"]) -> None: ...

global___ToStringTransformer = ToStringTransformer

@typing.final
class SharderTransformer(google.protobuf.message.Message):
    """Set the number of shards for particular tables and a list of columns whose
    values will be used for calculating a hash to determine a shard.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    SHARDS_COUNT_FIELD_NUMBER: builtins.int
    shards_count: builtins.int
    """Number of shards"""
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables"""

    @property
    def columns(self) -> global___ColumnsFilter:
        """List of included and excluded columns"""

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        columns: global___ColumnsFilter | None = ...,
        shards_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["columns", b"columns", "tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "shards_count", b"shards_count", "tables", b"tables"]) -> None: ...

global___SharderTransformer = SharderTransformer

@typing.final
class TableSplitterTransformer(google.protobuf.message.Message):
    """A transfer splits the X table into multiple tables (X_1, X_2, ..., X_n) based on
    data.
    If a row was located in the X table before it was split, it is now in the X_i
    table,
    where i is determined by the column list and split string parameters.
    Example:
    If the column list has two columns, month of birth and gender, specified and the
    split string states @,
    information about an employee whose name is John and who was born on February
    11, 1984,
    from the Employees table will get to a new table named Employees@February@male.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    SPLITTER_FIELD_NUMBER: builtins.int
    splitter: builtins.str
    """Specify the split string to be used for merging components in a new table name."""
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables"""

    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Specify the columns in the tables to be partitioned."""

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        columns: collections.abc.Iterable[builtins.str] | None = ...,
        splitter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "splitter", b"splitter", "tables", b"tables"]) -> None: ...

global___TableSplitterTransformer = TableSplitterTransformer

@typing.final
class FilterRowsTransformer(google.protobuf.message.Message):
    """This filter only applies to transfers with queues (Logbroker or Apache Kafka®)
    as a data source.
    When running a transfer, only the strings meeting the specified criteria remain
    in a changefeed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    filter: builtins.str
    """Filtering criterion. This can be comparison operators for numeric, string, and
    Boolean values,
    comparison to NULL, and checking whether a substring is part of a string.
    Details here:
    https://yandex.cloud/en-ru/docs/data-transfer/concepts/data-transformation#append-only-sources
    """
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables"""

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "tables", b"tables"]) -> None: ...

global___FilterRowsTransformer = FilterRowsTransformer

@typing.final
class Transformer(google.protobuf.message.Message):
    """Some transformers may have limitations and only apply to some source-target
    pairs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MASK_FIELD_FIELD_NUMBER: builtins.int
    FILTER_COLUMNS_FIELD_NUMBER: builtins.int
    RENAME_TABLES_FIELD_NUMBER: builtins.int
    REPLACE_PRIMARY_KEY_FIELD_NUMBER: builtins.int
    CONVERT_TO_STRING_FIELD_NUMBER: builtins.int
    SHARDER_TRANSFORMER_FIELD_NUMBER: builtins.int
    TABLE_SPLITTER_TRANSFORMER_FIELD_NUMBER: builtins.int
    FILTER_ROWS_FIELD_NUMBER: builtins.int
    @property
    def mask_field(self) -> global___MaskFieldTransformer: ...
    @property
    def filter_columns(self) -> global___FilterColumnsTransformer: ...
    @property
    def rename_tables(self) -> global___RenameTablesTransformer: ...
    @property
    def replace_primary_key(self) -> global___ReplacePrimaryKeyTransformer: ...
    @property
    def convert_to_string(self) -> global___ToStringTransformer: ...
    @property
    def sharder_transformer(self) -> global___SharderTransformer: ...
    @property
    def table_splitter_transformer(self) -> global___TableSplitterTransformer: ...
    @property
    def filter_rows(self) -> global___FilterRowsTransformer: ...
    def __init__(
        self,
        *,
        mask_field: global___MaskFieldTransformer | None = ...,
        filter_columns: global___FilterColumnsTransformer | None = ...,
        rename_tables: global___RenameTablesTransformer | None = ...,
        replace_primary_key: global___ReplacePrimaryKeyTransformer | None = ...,
        convert_to_string: global___ToStringTransformer | None = ...,
        sharder_transformer: global___SharderTransformer | None = ...,
        table_splitter_transformer: global___TableSplitterTransformer | None = ...,
        filter_rows: global___FilterRowsTransformer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["convert_to_string", b"convert_to_string", "filter_columns", b"filter_columns", "filter_rows", b"filter_rows", "mask_field", b"mask_field", "rename_tables", b"rename_tables", "replace_primary_key", b"replace_primary_key", "sharder_transformer", b"sharder_transformer", "table_splitter_transformer", b"table_splitter_transformer", "transformer", b"transformer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["convert_to_string", b"convert_to_string", "filter_columns", b"filter_columns", "filter_rows", b"filter_rows", "mask_field", b"mask_field", "rename_tables", b"rename_tables", "replace_primary_key", b"replace_primary_key", "sharder_transformer", b"sharder_transformer", "table_splitter_transformer", b"table_splitter_transformer", "transformer", b"transformer"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["transformer", b"transformer"]) -> typing.Literal["mask_field", "filter_columns", "rename_tables", "replace_primary_key", "convert_to_string", "sharder_transformer", "table_splitter_transformer", "filter_rows"] | None: ...

global___Transformer = Transformer

@typing.final
class Transformation(google.protobuf.message.Message):
    """Transformation is converting data using special transformer functions.
    These functions are executed on a data stream, applied to each data change item,
    and transform them.
    A transformer can be run at both the metadata and data levels.
    Data can only be transformed if the source and target are of different types.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFORMERS_FIELD_NUMBER: builtins.int
    @property
    def transformers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Transformer]:
        """Transformers are set as a list.
        When activating a transfer, a transformation plan is made for the tables that
        match the specified criteria.
        Transformers are applied to the tables in the sequence specified in the list.
        """

    def __init__(
        self,
        *,
        transformers: collections.abc.Iterable[global___Transformer] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["transformers", b"transformers"]) -> None: ...

global___Transformation = Transformation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.apploadbalancer.v1.virtual_host_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetVirtualHostRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    VIRTUAL_HOST_NAME_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router that the virtual host belongs to.

    To get the HTTP router ID, make a [HttpRouterService.List] request.
    """
    virtual_host_name: builtins.str
    """Name of the virtual host to return.

    To get the virtual host name, make a [VirtualHostService.List] request.
    """
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        virtual_host_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id", "virtual_host_name", b"virtual_host_name"]) -> None: ...

global___GetVirtualHostRequest = GetVirtualHostRequest

@typing.final
class ListVirtualHostsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router to list virtual hosts in.

    To get the HTTP router ID, make a [HttpRouterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListVirtualHostsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListVirtualHostsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListVirtualHostsRequest = ListVirtualHostsRequest

@typing.final
class ListVirtualHostsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIRTUAL_HOSTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListVirtualHostsRequest.page_size], use `next_page_token` as the value
    for the [ListVirtualHostsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def virtual_hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost]:
        """List of virtual hosts of the specified HTTP router."""

    def __init__(
        self,
        *,
        virtual_hosts: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "virtual_hosts", b"virtual_hosts"]) -> None: ...

global___ListVirtualHostsResponse = ListVirtualHostsResponse

@typing.final
class CreateVirtualHostRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHORITY_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    MODIFY_REQUEST_HEADERS_FIELD_NUMBER: builtins.int
    MODIFY_RESPONSE_HEADERS_FIELD_NUMBER: builtins.int
    ROUTE_OPTIONS_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router to create a virtual host in.

    To get the HTTP router ID, make a [HttpRouterService.List] request.
    """
    name: builtins.str
    """Name of the virtual host. The name must be unique within the HTTP router and cannot be changed after creation."""
    @property
    def authority(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of domains that are attributed to the virtual host.

        The host is selected to process the request received by the load balancer
        if the domain specified in the HTTP/1.1 `Host` header or the HTTP/2 `:authority` pseudo-header matches a domain
        specified in the host.

        A wildcard asterisk character (`*`) matches 0 or more characters.

        If not specified, all domains are attributed to the host, which is the same as specifying a `*` value.
        An HTTP router must not contain more than one virtual host to which all domains are attributed.
        """

    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.Route]:
        """Routes of the virtual host.

        A route contains a set of conditions (predicates) that are used by the load balancer to select the route
        for the request and an action on the request.
        For details about the concept, see [documentation](/docs/application-load-balancer/concepts/http-router#routes).

        The order of routes matters: the first route whose predicate matches the request is selected.
        The most specific routes should be at the top of the list, so that they are not overridden.
        For example, if the first HTTP route is configured, via [HttpRoute.match], to match paths prefixed with just `/`,
        other routes are never matched.
        """

    @property
    def modify_request_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.HeaderModification]:
        """Modifications that are made to the headers of incoming HTTP requests before they are forwarded to backends."""

    @property
    def modify_response_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.HeaderModification]:
        """Modifications that are made to the headers of HTTP responses received from backends
        before responses are forwarded to clients.
        """

    @property
    def route_options(self) -> yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions:
        """Route options for the virtual host."""

    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        name: builtins.str = ...,
        authority: collections.abc.Iterable[builtins.str] | None = ...,
        routes: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.Route] | None = ...,
        modify_request_headers: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.HeaderModification] | None = ...,
        modify_response_headers: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.HeaderModification] | None = ...,
        route_options: yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["route_options", b"route_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["authority", b"authority", "http_router_id", b"http_router_id", "modify_request_headers", b"modify_request_headers", "modify_response_headers", b"modify_response_headers", "name", b"name", "route_options", b"route_options", "routes", b"routes"]) -> None: ...

global___CreateVirtualHostRequest = CreateVirtualHostRequest

@typing.final
class CreateVirtualHostMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    VIRTUAL_HOST_NAME_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router that the virtual host is being created in."""
    virtual_host_name: builtins.str
    """Name of the virtual host that is being created."""
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        virtual_host_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id", "virtual_host_name", b"virtual_host_name"]) -> None: ...

global___CreateVirtualHostMetadata = CreateVirtualHostMetadata

@typing.final
class UpdateVirtualHostRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    VIRTUAL_HOST_NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    AUTHORITY_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    MODIFY_REQUEST_HEADERS_FIELD_NUMBER: builtins.int
    MODIFY_RESPONSE_HEADERS_FIELD_NUMBER: builtins.int
    ROUTE_OPTIONS_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router to update a virtual host in.

    To get the HTTP router ID, make a [HttpRouterService.List] request.
    """
    virtual_host_name: builtins.str
    """Name of the virtual host.

    Used only to refer to the virtual host. The name of a host cannot be changed.

    To get the virtual host name, make a [VirtualHostService.List] request.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the virtual host should be updated."""

    @property
    def authority(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """New list of domains to attribute to the virtual host.

        The host is selected to process the request received by the load balancer
        if the domain specified in the HTTP/1.1 `Host` header or the HTTP/2 `:authority` pseudo-header matches a domain
        specified in the host.

        A wildcard asterisk character (`*`) matches 0 or more characters.

        Existing list of domains is completely replaced by the specified list.

        If not specified, all domains are attributed to the host, which is the same as specifying a `*` value.
        An HTTP router must not contain more than one virtual host to which all domains are attributed.
        """

    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.Route]:
        """New list of routes of the virtual host.

        A route contains a set of conditions (predicates) that are used by the load balancer to select the route
        for the request and an action on the request.
        For details about the concept, see [documentation](/docs/application-load-balancer/concepts/http-router#routes).

        The order of routes matters: the first route whose predicate matches the request is selected.
        The most specific routes should be at the top of the list, so that they are not overridden.
        For example, if the first HTTP route is configured, via [HttpRoute.match], to match paths prefixed with just `/`,
        other routes are never matched.

        Existing list of routes is completely replaced by the specified list, so if you just want to remove a route,
        make a [VirtualHostService.RemoveRoute] request.
        """

    @property
    def modify_request_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.HeaderModification]:
        """New list of modifications that are made to the headers of incoming HTTP requests
        before they are forwarded to backends.

        Existing list of modifications is completely replaced by the specified list.
        """

    @property
    def modify_response_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.HeaderModification]:
        """New list of modifications that are made to the headers of HTTP responses received from backends
        before responses are forwarded to clients.

        Existing list of modifications is completely replaced by the specified list.
        """

    @property
    def route_options(self) -> yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions:
        """New route options for the virtual host."""

    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        virtual_host_name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        authority: collections.abc.Iterable[builtins.str] | None = ...,
        routes: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.Route] | None = ...,
        modify_request_headers: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.HeaderModification] | None = ...,
        modify_response_headers: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.HeaderModification] | None = ...,
        route_options: yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["route_options", b"route_options", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["authority", b"authority", "http_router_id", b"http_router_id", "modify_request_headers", b"modify_request_headers", "modify_response_headers", b"modify_response_headers", "route_options", b"route_options", "routes", b"routes", "update_mask", b"update_mask", "virtual_host_name", b"virtual_host_name"]) -> None: ...

global___UpdateVirtualHostRequest = UpdateVirtualHostRequest

@typing.final
class UpdateVirtualHostMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    VIRTUAL_HOST_NAME_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router that the virtual host is being updated in."""
    virtual_host_name: builtins.str
    """Name of the virtual host that is being updated."""
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        virtual_host_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id", "virtual_host_name", b"virtual_host_name"]) -> None: ...

global___UpdateVirtualHostMetadata = UpdateVirtualHostMetadata

@typing.final
class DeleteVirtualHostRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    VIRTUAL_HOST_NAME_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router to delete a virtual host from.

    To get the HTTP router ID, make a [HttpRouterService.List] request.
    """
    virtual_host_name: builtins.str
    """Name of the virtual host to delete.

    To get the virtual host name, make a [VirtualHostService.List] request.
    """
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        virtual_host_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id", "virtual_host_name", b"virtual_host_name"]) -> None: ...

global___DeleteVirtualHostRequest = DeleteVirtualHostRequest

@typing.final
class DeleteVirtualHostMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    VIRTUAL_HOST_NAME_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router that the virtual host is being deleted from."""
    virtual_host_name: builtins.str
    """Name of the virtual host that is being deleted."""
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        virtual_host_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id", "virtual_host_name", b"virtual_host_name"]) -> None: ...

global___DeleteVirtualHostMetadata = DeleteVirtualHostMetadata

@typing.final
class RemoveRouteRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    VIRTUAL_HOST_NAME_FIELD_NUMBER: builtins.int
    ROUTE_NAME_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router to delete a route from.

    To get the HTTP router ID, make a [HttpRouterService.List] request.
    """
    virtual_host_name: builtins.str
    """Name of the virtual host to delete a route from.

    To get the virtual host name, make a [VirtualHostService.List] request.
    """
    route_name: builtins.str
    """Name of the route to delete.

    To get the route name, make a [VirtualHostService.Get] request.
    """
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        virtual_host_name: builtins.str = ...,
        route_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id", "route_name", b"route_name", "virtual_host_name", b"virtual_host_name"]) -> None: ...

global___RemoveRouteRequest = RemoveRouteRequest

@typing.final
class RemoveRouteMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    VIRTUAL_HOST_NAME_FIELD_NUMBER: builtins.int
    ROUTE_NAME_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router that the route is being deleted from."""
    virtual_host_name: builtins.str
    """Name of the virtual host that the route is being deleted from."""
    route_name: builtins.str
    """Name of the route that is being deleted."""
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        virtual_host_name: builtins.str = ...,
        route_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id", "route_name", b"route_name", "virtual_host_name", b"virtual_host_name"]) -> None: ...

global___RemoveRouteMetadata = RemoveRouteMetadata

@typing.final
class UpdateRouteRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    VIRTUAL_HOST_NAME_FIELD_NUMBER: builtins.int
    ROUTE_NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    GRPC_FIELD_NUMBER: builtins.int
    ROUTE_OPTIONS_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router to update a route in.

    To get the HTTP router ID, make a [HttpRouterService.List] request.
    """
    virtual_host_name: builtins.str
    """Name of the virtual host to update a route in.

    To get the virtual host name, make a [VirtualHostService.List] request.
    """
    route_name: builtins.str
    """Name of the route to update.

    To get the route name, make a [VirtualHostService.Get] request.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the route should be updated."""

    @property
    def http(self) -> yandex.cloud.apploadbalancer.v1.virtual_host_pb2.HttpRoute:
        """New settings of the HTTP route."""

    @property
    def grpc(self) -> yandex.cloud.apploadbalancer.v1.virtual_host_pb2.GrpcRoute:
        """New settings of the gRPC route."""

    @property
    def route_options(self) -> yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions:
        """New route options for the route."""

    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        virtual_host_name: builtins.str = ...,
        route_name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        http: yandex.cloud.apploadbalancer.v1.virtual_host_pb2.HttpRoute | None = ...,
        grpc: yandex.cloud.apploadbalancer.v1.virtual_host_pb2.GrpcRoute | None = ...,
        route_options: yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["grpc", b"grpc", "http", b"http", "route", b"route", "route_options", b"route_options", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["grpc", b"grpc", "http", b"http", "http_router_id", b"http_router_id", "route", b"route", "route_name", b"route_name", "route_options", b"route_options", "update_mask", b"update_mask", "virtual_host_name", b"virtual_host_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["route", b"route"]) -> typing.Literal["http", "grpc"] | None: ...

global___UpdateRouteRequest = UpdateRouteRequest

@typing.final
class UpdateRouteMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    VIRTUAL_HOST_NAME_FIELD_NUMBER: builtins.int
    ROUTE_NAME_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router that the route is being updated in."""
    virtual_host_name: builtins.str
    """Name of the virtual host that the route is being updated in."""
    route_name: builtins.str
    """Name of the route that is being updated."""
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        virtual_host_name: builtins.str = ...,
        route_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id", "route_name", b"route_name", "virtual_host_name", b"virtual_host_name"]) -> None: ...

global___UpdateRouteMetadata = UpdateRouteMetadata
